@@ -3,9 +3,9 @@
 package App::perlmv;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-02'; # DATE
+our $DATE = '2020-08-03'; # DATE
 our $DIST = 'App-perlmv'; # DIST
-our $VERSION = '0.600'; # VERSION
+our $VERSION = '0.601'; # VERSION
 
 use 5.010001;
 use strict;
@@ -50,6 +50,7 @@ sub new {
         process_symlink => 1,
         recursive       => 0,
         verbose         => 0,
+        args            => {},
     };
 
     bless $self, $class;
@@ -116,6 +117,7 @@ sub parse_opts {
         'V|version'       => sub { $self->print_version()          },
         # we use \scalar to differentiate between -x and -e
         'x|execute=s'     => sub { push @{$self->{'codes'}}, \$_[1]},
+        'a|arg=s%'        => $self->{'args'},
         '<>'              => sub { $self->parse_extra_opts(@_)     },
     ) or $self->print_help();
 }
@@ -256,6 +258,7 @@ Options:
  -x <NAME> Execute a scriptlet. Can be specified multiple times. -x is optional
      if there is only one scriptlet to execute, and scriptlet name is specified
      as the first argument, and there is no -e specified.
+ -a <arg=value> (--arg) Supply arguments for code/scriptlet.
 
 USAGE
 
@@ -271,6 +274,7 @@ sub get_scriptlet_code {
         (my $mod_pm = "$mod.pm") =~ s!::!/!g;
         require $mod_pm;
         no strict 'refs';
+        ${"$mod\::SCRIPTLET"} or die "Package $mod does not define \$SCRIPTLET";
         ${"$mod\::SCRIPTLET"}->{code};
     } else {
         $self->{'scriptlets'}{$name}{'code'};
@@ -385,6 +389,7 @@ sub compile_code {
     local $_ = "-TEST";
     local $App::perlmv::code::TESTING = 1;
     local $App::perlmv::code::COMPILING = 1;
+    local $App::perlmv::code::ARGS = $self->{'args'};
     eval "package App::perlmv::code; $code";
     die "FATAL: Code doesn't compile: code=$code, errmsg=$@\n" if $@;
 }
@@ -395,6 +400,7 @@ sub run_code_for_cleaning {
     no warnings;
     local $_ = "-CLEAN";
     local $App::perlmv::code::CLEANING = 1;
+    local $App::perlmv::code::ARGS = $self->{'args'};
     if (ref $code eq 'CODE') {
         $code->();
     } else {
@@ -410,6 +416,7 @@ sub run_code {
     my $orig_ = $_;
     local $App::perlmv::code::TESTING = 0;
     local $App::perlmv::code::COMPILING = 0;
+    local $App::perlmv::code::ARGS = $self->{'args'};
     my $res;
     if (ref $code eq 'CODE') {
         $res = $code->();
@@ -631,7 +638,7 @@ App::perlmv - Rename files using Perl code
 
 =head1 VERSION
 
-This document describes version 0.600 of App::perlmv (from Perl distribution App-perlmv), released on 2020-08-02.
+This document describes version 0.601 of App::perlmv (from Perl distribution App-perlmv), released on 2020-08-03.
 
 =for Pod::Coverage ^(.*)$
 
